@@ -9,7 +9,11 @@ from samtranslator.model.intrinsics import fnJoin, is_intrinsic
 from samtranslator.model.resource_policies import ResourcePolicies
 from samtranslator.model.role_utils import construct_role_for_resource
 from samtranslator.model.s3_utils.uri_parser import parse_s3_uri
-from samtranslator.model.stepfunctions.resources import StepFunctionsStateMachine
+from samtranslator.model.stepfunctions.resources import (
+    StepFunctionsStateMachine,
+    StepFunctionsStateMachineAlias,
+    StepFunctionsStateMachineVersion,
+)
 from samtranslator.model.tags.resource_tagging import get_tag_list
 from samtranslator.model.xray_utils import get_xray_managed_policy_name
 from samtranslator.utils.cfn_dynamic_references import is_dynamic_reference
@@ -24,7 +28,7 @@ class StateMachineGenerator:
         "Specify either 'Role' or 'Policies' (but not both at the same time) or neither of them"
     )
 
-    def __init__(  # type: ignore[no-untyped-def] # noqa: too-many-arguments
+    def __init__(  # type: ignore[no-untyped-def] # noqa: PLR0913
         self,
         logical_id,
         depends_on,
@@ -48,6 +52,9 @@ class StateMachineGenerator:
         resource_attributes=None,
         passthrough_resource_attributes=None,
         get_managed_policy_map=None,
+        auto_publish_alias=None,
+        deployment_preference=None,
+        use_alias_as_event_target=None,
     ):
         """
         Constructs an State Machine Generator class that generates a State Machine resource
@@ -73,6 +80,9 @@ class StateMachineGenerator:
         :param tags: Tags to be associated with the State Machine resource
         :param resource_attributes: Resource attributes to add to the State Machine resource
         :param passthrough_resource_attributes: Attributes such as `Condition` that are added to derived resources
+        :param auto_publish_alias: Name of the state machine alias to automatically create and update
+        :deployment_preference: Settings to enable gradual state machine deployments
+        :param use_alias_as_event_target: Whether to use the state machine alias as the event target
         """
         self.logical_id = logical_id
         self.depends_on = depends_on
@@ -100,6 +110,9 @@ class StateMachineGenerator:
         )
         self.substitution_counter = 1
         self.get_managed_policy_map = get_managed_policy_map
+        self.auto_publish_alias = auto_publish_alias
+        self.deployment_preference = deployment_preference
+        self.use_alias_as_event_target = use_alias_as_event_target
 
     @cw_timer(prefix="Generator", name="StateMachine")
     def to_cloudformation(self):  # type: ignore[no-untyped-def]
@@ -152,6 +165,9 @@ class StateMachineGenerator:
         self.state_machine.TracingConfiguration = self.tracing
         self.state_machine.Tags = self._construct_tag_list()
 
+        managed_traffic_shifting_resources = self._generate_managed_traffic_shifting_resources()
+        resources.extend(managed_traffic_shifting_resources)
+
         event_resources = self._generate_event_resources()
         resources.extend(event_resources)
 
@@ -241,6 +257,78 @@ class StateMachineGenerator:
         sam_tag = {self._SAM_KEY: self._SAM_VALUE}
         return get_tag_list(sam_tag) + get_tag_list(self.tags)
 
+    def _construct_version(self) -> StepFunctionsStateMachineVersion:
+        """Constructs a state machine version resource that will be auto-published when the revision id of the state machine changes.
+
+        :return: Step Functions state machine version resource
+        """
+
+        # Unlike Lambda function versions, state machine versions do not need a hash suffix because
+        # they are always replaced when their corresponding state machine is updated.
+        # I.e. A SAM StateMachine resource will never have multiple version resources at the same time.
+        logical_id = f"{self.logical_id}Version"
+        attributes = self.passthrough_resource_attributes.copy()
+
+        # Both UpdateReplacePolicy and DeletionPolicy are needed to protect previous version from deletion
+        # to ensure gradual deployment works.
+        if "DeletionPolicy" not in attributes:
+            attributes["DeletionPolicy"] = "Retain"
+        if "UpdateReplacePolicy" not in attributes:
+            attributes["UpdateReplacePolicy"] = "Retain"
+
+        state_machine_version = StepFunctionsStateMachineVersion(logical_id=logical_id, attributes=attributes)
+        state_machine_version.StateMachineArn = self.state_machine.get_runtime_attr("arn")
+        state_machine_version.StateMachineRevisionId = self.state_machine.get_runtime_attr("state_machine_revision_id")
+
+        return state_machine_version
+
+    def _construct_alias(self, version: StepFunctionsStateMachineVersion) -> StepFunctionsStateMachineAlias:
+        """Constructs a state machine alias resource pointing to the given state machine version.
+        :return: Step Functions state machine alias resource
+        """
+        logical_id = f"{self.logical_id}Alias{self.auto_publish_alias}"
+        attributes = self.passthrough_resource_attributes
+
+        state_machine_alias = StepFunctionsStateMachineAlias(logical_id=logical_id, attributes=attributes)
+        state_machine_alias.Name = self.auto_publish_alias
+
+        state_machine_version_arn = version.get_runtime_attr("arn")
+
+        deployment_preference = {}
+        if self.deployment_preference:
+            deployment_preference = self.deployment_preference
+        else:
+            deployment_preference["Type"] = "ALL_AT_ONCE"
+
+        deployment_preference["StateMachineVersionArn"] = state_machine_version_arn
+        state_machine_alias.DeploymentPreference = deployment_preference
+
+        self.state_machine_alias = state_machine_alias
+
+        return state_machine_alias
+
+    def _generate_managed_traffic_shifting_resources(
+        self,
+    ) -> List[Any]:
+        """Generates and returns the version and alias resources associated with this state machine's managed traffic shifting.
+
+        :returns: a list containing the state machine's version and alias resources
+        :rtype: list
+        """
+        if not self.auto_publish_alias and self.use_alias_as_event_target:
+            raise InvalidResourceException(
+                self.logical_id, "'UseAliasAsEventTarget' requires 'AutoPublishAlias' property to be specified."
+            )
+        if not self.auto_publish_alias and not self.deployment_preference:
+            return []
+        if not self.auto_publish_alias and self.deployment_preference:
+            raise InvalidResourceException(
+                self.logical_id, "'DeploymentPreference' requires 'AutoPublishAlias' property to be specified."
+            )
+
+        state_machine_version = self._construct_version()
+        return [state_machine_version, self._construct_alias(state_machine_version)]
+
     def _generate_event_resources(self) -> List[Dict[str, Any]]:
         """Generates and returns the resources associated with this state machine's event sources.
 
@@ -262,7 +350,12 @@ class StateMachineGenerator:
                         kwargs[name] = resource
                 except (TypeError, AttributeError) as e:
                     raise InvalidEventException(logical_id, str(e)) from e
-                resources += eventsource.to_cloudformation(resource=self.state_machine, **kwargs)
+                target_resource = (
+                    (self.state_machine_alias or self.state_machine)
+                    if self.use_alias_as_event_target
+                    else self.state_machine
+                )
+                resources += eventsource.to_cloudformation(resource=target_resource, **kwargs)
 
         return resources
 
@@ -303,7 +396,7 @@ class StateMachineGenerator:
         else:
             return dynamic_value_paths
 
-        for key, value in sorted(iterator, key=lambda item: item[0]):  # type: ignore[no-any-return]
+        for key, value in sorted(iterator, key=lambda item: item[0]):
             if is_intrinsic(value) or is_dynamic_reference(value):
                 dynamic_value_paths.append([*path, key])
             elif isinstance(value, (dict, list)):
